fx.ring.response


bad-request>clj

(bad-request>)
(bad-request> eff-or-body)
(bad-request> eff body)

Transforms the value of eff into a 400 Bad Request Ring response map, or creates a 400 Bad Request response effect.

Transforms the value of `eff` into a 400 Bad Request Ring response map,
or creates a 400 Bad Request response effect.
raw docstring

content-type>clj

(content-type> content-type-str)
(content-type> eff content-type-str)

Sets the Content-Type header on the response produced by upstream effect.

Sets the Content-Type header on the response produced by upstream effect.
raw docstring

created>clj

(created>)
(created> eff-or-url)
(created> eff-or-url url-or-body)
(created> eff url body)

Transforms the value of eff into a 201 Created Ring response map, or creates a 201 Created response effect.

Transforms the value of `eff` into a 201 Created Ring response map,
or creates a 201 Created response effect.
raw docstring

header>clj

(header> header-name header-val)
(header> eff header-name header-val)

Adds an HTTP header to the response produced by upstream effect.

Adds an HTTP header to the response produced by upstream effect.
raw docstring

internal-server-error>clj

(internal-server-error>)
(internal-server-error> eff-or-body)
(internal-server-error> eff body)

Transforms the value of eff into a 500 Internal Server Error Ring response map, or creates a 500 Internal Server Error response effect.

Transforms the value of `eff` into a 500 Internal Server Error Ring response map,
or creates a 500 Internal Server Error response effect.
raw docstring

not-found>clj

(not-found>)
(not-found> eff-or-body)
(not-found> eff body)

Transforms the value of eff into a 404 Not Found Ring response map, or creates a 404 Not Found response effect.

Transforms the value of `eff` into a 404 Not Found Ring response map,
or creates a 404 Not Found response effect.
raw docstring

ok>clj

(ok>)
(ok> eff-or-body)
(ok> eff body)

Transforms the value of eff into a 200 OK Ring response map, or creates a 200 OK response effect from a static body.

Transforms the value of `eff` into a 200 OK Ring response map,
or creates a 200 OK response effect from a static `body`.
raw docstring

redirect>clj

(redirect> url)
(redirect> eff-or-url url-or-status)
(redirect> eff url status-code)

Creates an effect yielding a 302 (or custom status) Redirect Ring response map.

Creates an effect yielding a 302 (or custom status) Redirect Ring response map.
raw docstring

request-keyclj


request>clj

(request>)
(request> key)
(request> key default-val)

Creates an effect yielding the active Ring request map (or a field) from context.

Creates an effect yielding the active Ring request map (or a field) from context.
raw docstring

response>clj

(response>)
(response> eff-or-body)
(response> eff body)

Transforms the value of eff into a standard 200 Ring response map, or creates a 200 response effect from a static body.

Transforms the value of `eff` into a standard 200 Ring response map,
or creates a 200 response effect from a static `body`.
raw docstring

status>clj

(status> status-code)
(status> eff status-code)

Sets the HTTP status code on the response produced by upstream effect.

Sets the HTTP status code on the response produced by upstream effect.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries