fx.ring.response


bad-request>clj

(bad-request>)
(bad-request> body)
(bad-request> eff body)

Creates an effect yielding a 400 Bad Request Ring response map.

Creates an effect yielding a 400 Bad Request Ring response map.
raw docstring

content-type>clj

(content-type> content-type-str)
(content-type> eff content-type-str)

Sets the Content-Type header on the response produced by upstream effect.

Sets the Content-Type header on the response produced by upstream effect.
raw docstring

created>clj

(created> url)
(created> url body)
(created> eff url body)

Creates an effect yielding a 201 Created Ring response map.

Creates an effect yielding a 201 Created Ring response map.
raw docstring

header>clj

(header> header-name header-val)
(header> eff header-name header-val)

Adds an HTTP header to the response produced by upstream effect.

Adds an HTTP header to the response produced by upstream effect.
raw docstring

internal-server-error>clj

(internal-server-error>)
(internal-server-error> body)
(internal-server-error> eff body)

Creates an effect yielding a 500 Internal Server Error Ring response map.

Creates an effect yielding a 500 Internal Server Error Ring response map.
raw docstring

not-found>clj

(not-found>)
(not-found> body)
(not-found> eff body)

Creates an effect yielding a 404 Not Found Ring response map.

Creates an effect yielding a 404 Not Found Ring response map.
raw docstring

ok>clj

(ok>)
(ok> body)
(ok> eff body)

Creates an effect yielding a 200 OK Ring response map wrapping body.

Creates an effect yielding a 200 OK Ring response map wrapping `body`.
raw docstring

redirect>clj

(redirect> url)
(redirect> url status-code)
(redirect> eff url status-code)

Creates an effect yielding a 302 (or custom status) Redirect Ring response map.

Creates an effect yielding a 302 (or custom status) Redirect Ring response map.
raw docstring

request-keyclj


request>clj

(request>)
(request> key)
(request> key default-val)

Creates an effect yielding the active Ring request map (or a field) from context.

Creates an effect yielding the active Ring request map (or a field) from context.
raw docstring

response>clj

(response> body)
(response> eff body)

Creates an effect yielding a standard 200 Ring response map wrapping body.

Creates an effect yielding a standard 200 Ring response map wrapping `body`.
raw docstring

status>clj

(status> status-code)
(status> eff status-code)

Sets the HTTP status code on the response produced by upstream effect.

Sets the HTTP status code on the response produced by upstream effect.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries